@@ -1662,8 +1662,8 @@ AppleII::ProDOS - Access files on Apple II ProDOS disk images
 =head1 VERSION
 
 This document describes version 0.10 of
-AppleII::ProDOS, released December 12, 2011
-as part of LibA2 version 0.10.
+AppleII::ProDOS, released December 26, 2013
+as part of LibA2 version 0.11.
 
 =head1 SYNOPSIS
 
@@ -2015,11 +2015,11 @@ or through the web interface at
 L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=LibA2 >>.
 
 You can follow or contribute to LibA2's development at
-L<< http://github.com/madsen/perl-libA2 >>.
+L<< https://github.com/madsen/perl-libA2 >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Christopher J. Madsen.
+This software is copyright (c) 2013 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
